Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(542)

Unified Diff: services/ui/ws/server_window_delegate.h

Issue 2797453002: Rename DisplayCompositor to MojoFrameSinkManager. (Closed)
Patch Set: Rebase. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/ws/server_window_delegate.h
diff --git a/services/ui/ws/server_window_delegate.h b/services/ui/ws/server_window_delegate.h
index 8caf5bf0b90bd8b2379f31491788a957c681921e..d9ed330aae78120bfb6dc6389d1379a8cfca8966 100644
--- a/services/ui/ws/server_window_delegate.h
+++ b/services/ui/ws/server_window_delegate.h
@@ -7,10 +7,15 @@
#include <memory>
-#include "cc/ipc/display_compositor.mojom.h"
#include "services/ui/public/interfaces/mus_constants.mojom.h"
#include "services/ui/public/interfaces/window_tree.mojom.h"
+namespace cc {
+namespace mojom {
+class FrameSinkManager;
+}
+}
+
namespace ui {
namespace ws {
@@ -19,9 +24,9 @@ class ServerWindow;
class ServerWindowDelegate {
public:
- // Returns a display compositor interface pointer. There is only one
- // DisplayCompositor running in the system.
- virtual cc::mojom::DisplayCompositor* GetDisplayCompositor() = 0;
+ // Returns a frame sink manager interface pointer. There is only one
+ // MojoFrameSinkManager running in the system.
+ virtual cc::mojom::FrameSinkManager* GetFrameSinkManager() = 0;
// Returns the root of the window tree to which this |window| is attached.
// Returns null if this window is not attached up through to a root window.
« no previous file with comments | « services/ui/ws/server_window_compositor_frame_sink_manager.cc ('k') | services/ui/ws/test_server_window_delegate.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698